#ifndef NT2_INCLUDE_FUNCTIONS_ARG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ARG_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/arg.hpp>

#endif
